Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Build ¶
conds, vals := query.Build([]query.Conds{
{
Key: "sender_id = ? OR receiver_id = ?",
Values: query.V{accountId, accountId},
Skip: false,
},
})
Build([]Conds) will return a query string and a slice of values that can be used in the QueryContext method.
func ReplacePlaceholder ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.